create_widget()
Create a new widget with the given name and width.
Usage
create_widget(
name,
width=100,
)Parameters
name: str-
The name of the widget.
width: int = 100-
The width of the widget in pixels, by default 100.
Returns
dict-
A dictionary representing the created widget.
Examples
>>> create_widget("button")
{'name': 'button', 'width': 100}